@@ -48,9 +48,12 @@ class ActivitySummaryView(AnyRsetView):
 
 class ActivitySubmitView(EntityView):
     __regid__ = 'activities-submit'
-    __select__ = empty_rset | implements('Activity')
+    __select__ = empty_rset() | implements('Activity')
 
     def call(self, year=None, month=None, day=None):
+        year = year or self._cw.form.get('year')
+        month = month or self._cw.form.get('month')
+        day = day or self._cw.form.get('day')
         self.wview('activitytable', self.cw_rset, 'null')
         self._cw.user.view('euser-activities-submitform', w=self.w,
                            year=year, month=month, day=day)
@@ -91,7 +94,8 @@ class ActivityTable(EntityView):
         rset = self._cw.execute(rql)
         self.wview('editable-table', rset, 'null', #subvid='tablecontext',
                    displayfilter=True, displayactions=False,
-                   headers=headers, displaycols=displaycols)
+                   headers=headers, displaycols=displaycols,
+                   cellvids={3: 'editable-final'})
 
 
 class GenericActivityTable(tableview.EditableTableView):
