@@ -64,40 +64,18 @@ class CWUserActivitySubmitFormView(form.FormViewMixIn, EntityView):
     __select__ = one_line_rset() & implements('CWUser')
     domid = 'activityForm'
 
-    def cell_call(self, row, col, year=None, month=None, day=None, startup=False):
+    def cell_call(self, row, col, year=None, month=None, day=None, **kwargs):
         self._cw.add_css('cubicweb.form.css')
         user = self.cw_rset.get_entity(row, col)
-        year = year or self._cw.form.get('year')
-        month = month or self._cw.form.get('month')
-        day = day or self._cw.form.get('day')
         if year and month and day:
             date = datetime.date(int(year), int(month), int(day))
         else:
             date = datetime.date.today()
+        kwargs.setdefault('diem', date)
         self.w(u'<h2>%s</h2>' % self._cw._('declare activities').capitalize())
-        self._make_activity_form(user, date, startup)
+        self._make_activity_form(user, **kwargs)
 
-    def _build_redirect_url(self, date, startup):
-        html = u'<fieldset>'
-        if startup:
-            curpath = u'/'
-            errurl = self._cw.base_url()
-            params = None
-        else:
-            curpath = self._cw.relative_path(includeparams=False)
-            errurl = self._cw.url()
-            params = urlparse(errurl)[4]
-        html += u'<input type="hidden" name="__redirectpath" value="%s" />' % (
-            xml_escape(curpath))
-        if params:
-            html += u'<input type="hidden" name="__redirectparams" value="%s" />' % (
-                xml_escape(params))
-        html += u'<input type="hidden" name="__errorurl" value="%s" />' % (
-            xml_escape(self.session_key()))
-        html += u'</fieldset>'
-        return html
-
-    def _make_activity_form(self, cwuser, date, startup):
+    def _make_activity_form(self, cwuser, **formvalues):
         resource = cwuser.default_resource
         if resource is None:
             return u'<div class="error">%s</div>' % (
@@ -113,8 +91,8 @@ class CWUserActivitySubmitFormView(form.FormViewMixIn, EntityView):
                                     redirect_path=self._cw.relative_path(False))
         form.form_buttons = form.form_buttons[:1] # only keep ok button
         renderer = vreg['formrenderers'].select_or_none('htable', self._cw)
-        self.w(form.render(formvalues={'done_by':resource.eid, 'diem':date},
-                           renderer=renderer))
+        formvalues.setdefault('done_by', resource.eid)
+        self.w(form.render(formvalues=formvalues, renderer=renderer))
 
 
 
