@@ -74,7 +74,7 @@ def activity_done_for_choices(form, field, limit=None):
             options += sorted((entity.view('combobox'), entity.eid)
                               for entity in rset.entities())
         else:
-            options += [(req._('no workorders %s') % open_state,
+            options += [(req._('no workorders in state %s') % req._(open_state),
                          INTERNAL_FIELD_VALUE)]
         return options
     # for new entities, users will only see their matching resource
